@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2015 David Gobbi
+  Copyright (c) 2012-2019 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -14,7 +14,7 @@
 
 #include "progress.h"
 
-#include <vtkDICOMUtilities.h>
+#include "vtkDICOMUtilities.h"
 
 void ProgressObserver::Execute(vtkObject *, unsigned long e, void *vp)
 {
