@@ -1,6 +1,6 @@
 #include "vtkDICOMParser.h"
 #include "vtkDICOMMetaData.h"
-#include <vtkSmartPointer.h>
+#include "vtkSmartPointer.h"
 
 #include <sstream>
 
