@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2016 David Gobbi
+  Copyright (c) 2012-2019 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -27,15 +27,22 @@
 #include "vtkDICOMFile.h"
 #include "vtkDICOMFileDirectory.h"
 
-#include <vtkImageData.h>
-#include <vtkMatrix4x4.h>
-#include <vtkImageReslice.h>
-#include <vtkStringArray.h>
-#include <vtkIntArray.h>
-#include <vtkErrorCode.h>
-#include <vtkSortFileNames.h>
-#include <vtkSmartPointer.h>
+#include "vtkImageData.h"
+#include "vtkMatrix4x4.h"
+#include "vtkImageReslice.h"
+#include "vtkStringArray.h"
+#include "vtkIntArray.h"
+#include "vtkErrorCode.h"
+#include "vtkSortFileNames.h"
+#include "vtkSmartPointer.h"
+#include "vtkVersion.h"
 
+#if VTK_MAJOR_VERSION >= 6 || VTK_MINOR_VERSION >= 10
+#include "vtkImageResize.h"
+#include "vtkImageSincInterpolator.h"
+#endif
+
+#include <algorithm>
 #include <string>
 #include <vector>
 #include <set>
@@ -69,6 +76,7 @@ struct dicomtodicom_options
   const char *series_number;
   const char *uid_prefix;
   int mpr;
+  bool resample;
   bool silent;
   bool verbose;
   const char *output;
@@ -85,7 +93,7 @@ void dicomtodicom_version(FILE *file, const char *command_name, bool verbose)
   {
     fprintf(file, "%s %s\n", cp, DICOM_VERSION);
     fprintf(file, "\n"
-      "Copyright (c) 2012-2016, David Gobbi.\n\n"
+      "Copyright (c) 2012-2019, David Gobbi.\n\n"
       "This software is distributed under an open-source license.  See the\n"
       "Copyright.txt file that comes with the vtk-dicom source distribution.\n");
   }
@@ -112,6 +120,7 @@ void dicomtodicom_usage(FILE *file, const char *command_name)
     "  -o directory            The output directory.\n"
     "  -s --silent             Do not print anything while executing.\n"
     "  -v --verbose            Verbose error reporting.\n"
+    "  --resample              Resample to produce square pixels.\n"
     "  --axial                 Produce axial slices.\n"
     "  --coronal               Produce coronal slices.\n"
     "  --sagittal              Produce sagittal slices.\n"
@@ -158,7 +167,8 @@ void dicomtodicom_help(FILE *file, const char *command_name)
   fprintf(file,
     "Reformatting of the data (MPR) is permitted during the conversion.\n"
     "This is an experimental feature and causes much of the per-instance\n"
-    "meta data to be discarded.\n"
+    "meta data to be discarded.  Reformatting be combined with resampling\n"
+    "to produce an output with square pixels via Lanczos interpolation.\n"
     "\n");
 }
 
@@ -239,6 +249,7 @@ void dicomtodicom_read_options(
   options->series_description = 0;
   options->series_number = 0;
   options->uid_prefix = "2.25";
+  options->resample = false;
   options->silent = false;
   options->verbose = false;
   options->output = 0;
@@ -296,6 +307,10 @@ void dicomtodicom_read_options(
       {
         options->mpr = MPRSagittal;
       }
+      else if (strcmp(arg, "--resample") == 0)
+      {
+        options->resample = true;
+      }
       else if (strcmp(arg, "--silent") == 0)
       {
         options->silent = true;
@@ -399,25 +414,24 @@ void dicomtodicom_convert_one(
   vtkSmartPointer<vtkDICOMMetaData> meta =
     vtkSmartPointer<vtkDICOMMetaData>::New();
   meta->DeepCopy(reader->GetMetaData());
-  meta->SetAttributeValue(DC::SeriesNumber,
-    meta->GetAttributeValue(DC::SeriesNumber).AsUnsignedInt() +
+  meta->Set(DC::SeriesNumber, meta->Get(DC::SeriesNumber).AsUnsignedInt() +
     1000*(1 + options->mpr*100));
   std::string seriesDescription =
-    (meta->GetAttributeValue(DC::SeriesDescription).AsString() +
+    (meta->Get(DC::SeriesDescription).AsString() +
      dicomtodicom_description[options->mpr]);
   if (seriesDescription.size() < 64)
   {
-    meta->SetAttributeValue(DC::SeriesDescription, seriesDescription);
+    meta->Set(DC::SeriesDescription, seriesDescription);
   }
 
   // set the metadata supplied on the command line
   if (options->series_description)
   {
-    meta->SetAttributeValue(DC::SeriesDescription, options->series_description);
+    meta->Set(DC::SeriesDescription, options->series_description);
   }
   if (options->series_number)
   {
-    meta->SetAttributeValue(DC::SeriesNumber, options->series_number);
+    meta->Set(DC::SeriesNumber, options->series_number);
   }
 
   // get the matrix from the DICOM series
@@ -434,6 +448,10 @@ void dicomtodicom_convert_one(
     vtkSmartPointer<vtkImageReslice>::New();
   vtkSmartPointer<vtkDICOMCTRectifier> rectify =
     vtkSmartPointer<vtkDICOMCTRectifier>::New();
+#if VTK_MAJOR_VERSION >= 6 || VTK_MINOR_VERSION >= 10
+  vtkSmartPointer<vtkImageResize> resample =
+    vtkSmartPointer<vtkImageResize>::New();
+#endif
   vtkSmartPointer<vtkMatrix4x4> axes =
     vtkSmartPointer<vtkMatrix4x4>::New();
   int permutation[3] = { 0, 1, 2 };
@@ -451,6 +469,38 @@ void dicomtodicom_convert_one(
       matrix = rectify->GetRectifiedMatrix();
     }
 
+    // check if resampling was requested
+    if (options->resample)
+    {
+#if VTK_MAJOR_VERSION >= 6 || VTK_MINOR_VERSION >= 10
+      // generate cube voxels
+      double spacing[3] = { 1.0, 1.0, 1.0 };
+      const vtkDICOMValue& v = meta->Get(DC::PixelSpacing);
+      if (v.GetNumberOfValues() == 2)
+      {
+        v.GetValues(spacing, 2);
+        double s = std::min(spacing[0], spacing[1]);
+        spacing[0] = s;
+        spacing[1] = s;
+        spacing[2] = s;
+      }
+      resample->SetInputConnection(lastOutput);
+      vtkSmartPointer<vtkImageSincInterpolator> interpolator =
+        vtkSmartPointer<vtkImageSincInterpolator>::New();
+      interpolator->SetWindowFunctionToLanczos();
+      resample->SetInterpolator(interpolator);
+      resample->SetResizeMethodToOutputSpacing();
+      resample->SetOutputSpacing(spacing);
+      resample->InterpolateOn();
+      resample->BorderOn();
+      resample->Update();
+      lastOutput = resample->GetOutputPort();
+#else
+      fprintf(stderr,
+              "\nTo use --resample, recompile with VTK 5.10 or later.\n\n");
+#endif
+    }
+
     // create a permutation matrix to make the slices axial
     axes->DeepCopy(matrix);
     axes->Invert();
@@ -545,8 +595,7 @@ void dicomtodicom_convert_one(
   vtkDICOMGenerator *generator = 0;
 
   // get the generator from the supplied DICOM data
-  std::string SOPClass =
-    meta->GetAttributeValue(DC::SOPClassUID).AsString();
+  std::string SOPClass = meta->Get(DC::SOPClassUID).AsString();
   if (SOPClass == "1.2.840.10008.5.1.4.1.1.2" ||
       SOPClass == "1.2.840.10008.5.1.4.1.1.2.1" ||
       SOPClass == "1.2.840.10008.5.1.4.1.1.2.2")
