@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2015 David Gobbi
+  Copyright (c) 2012-2019 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -18,7 +18,7 @@
 #include "vtkImageData.h"
 #include "vtkStringArray.h"
 
-#include <vtkSmartPointer.h>
+#include "vtkSmartPointer.h"
 
 #include <stdio.h>
 #include <string.h>
