@@ -21,6 +21,7 @@
 #include "vtkDICOMFileSorter.h"
 #include "vtkDICOMMRGenerator.h"
 #include "vtkDICOMCTGenerator.h"
+#include "vtkDICOMSCGenerator.h"
 #include "vtkDICOMToRAS.h"
 #include "vtkDICOMCTRectifier.h"
 #include "vtkDICOMUtilities.h"
@@ -75,6 +76,7 @@ struct niftitodicom_options
   int mpr;
   bool silent;
   bool verbose;
+  bool verbatim;
   const char *output;
   const char *input;
 };
@@ -117,6 +119,7 @@ void niftitodicom_usage(FILE *file, const char *command_name)
     "  -o directory            The output directory.\n"
     "  -s --silent             Do not print anything while executing.\n"
     "  -v --verbose            Verbose error reporting.\n"
+    "  --verbatim              Copy source metadata nearly verbatim.\n"
     "  --no-reordering         Never reorder slices, rows, or columns.\n"
     "  --axial                 Produce axial slices.\n"
     "  --coronal               Produce coronal slices.\n"
@@ -264,6 +267,7 @@ void niftitodicom_read_options(
   options->uid_prefix = "2.25";
   options->silent = false;
   options->verbose = false;
+  options->verbatim = false;
   options->output = 0;
   options->input = 0;
 
@@ -332,6 +336,10 @@ void niftitodicom_read_options(
       {
         options->verbose = true;
       }
+      else if (strcmp(arg, "--verbatim") == 0)
+      {
+        options->verbatim = true;
+      }
       else if (strcmp(arg, "--version") == 0)
       {
         niftitodicom_version(stdout, argv[0], false);
@@ -746,37 +754,85 @@ void niftitodicom_convert_one(
     meta->Erase(DC::FrameOfReferenceUID);
   }
 
+  // the UIDs for the SOP classes we support
+  const char *classUID_CT = "1.2.840.10008.5.1.4.1.1.2";
+  const char *classUID_MR = "1.2.840.10008.5.1.4.1.1.4";
+  const char *classUID_SC = "1.2.840.10008.5.1.4.1.1.7";
+  std::string sourceClassUID = meta->Get(DC::SOPClassUID).AsString();
+  std::string outputClassUID;
+
   // make the generator
   vtkSmartPointer<vtkDICOMMRGenerator> mrgenerator =
     vtkSmartPointer<vtkDICOMMRGenerator>::New();
   vtkSmartPointer<vtkDICOMCTGenerator> ctgenerator =
     vtkSmartPointer<vtkDICOMCTGenerator>::New();
+  vtkSmartPointer<vtkDICOMSCGenerator> scgenerator =
+    vtkSmartPointer<vtkDICOMSCGenerator>::New();
+  vtkSmartPointer<vtkDICOMGenerator> verbgenerator =
+    vtkSmartPointer<vtkDICOMGenerator>::New();
   vtkDICOMGenerator *generator = mrgenerator;
-  if (options->modality)
+
+  if (options->verbatim)
+  {
+    generator = verbgenerator;
+  }
+  else if (options->modality)
   {
     if (strcmp(options->modality, "CT") == 0)
     {
       generator = ctgenerator;
+      outputClassUID = classUID_CT;
     }
     else if (strcmp(options->modality, "MR") == 0 ||
              strcmp(options->modality, "MRI") == 0)
     {
       generator = mrgenerator;
+      outputClassUID = classUID_MR;
     }
-    else
+    else if (strcmp(options->modality, "SC") == 0)
     {
-      generator = 0;
+      generator = scgenerator;
+      outputClassUID = classUID_SC;
     }
   }
+  else if (meta->Has(DC::SOPClassUID))
+  {
+    if (sourceClassUID == classUID_CT &&
+        (scalarType == VTK_SHORT || scalarType == VTK_UNSIGNED_SHORT))
+    {
+      generator = ctgenerator;
+      outputClassUID = classUID_CT;
+    }
+    else if (sourceClassUID == classUID_MR &&
+             (scalarType == VTK_SHORT || scalarType == VTK_UNSIGNED_SHORT))
+    {
+      generator = mrgenerator;
+      outputClassUID = classUID_MR;
+    }
+    else if (sourceClassUID == classUID_SC)
+    {
+      generator = scgenerator;
+      outputClassUID = classUID_SC;
+    }
+  }
+
+  if (sourceClassUID == outputClassUID)
+  {
+    // if the source data has the same SOP base class as the data that we
+    // are generating, then copy all attributes, otherwise only copy
+    // attributes that are part of the output's SOP base class.
+    generator->ExtendedOn();
+  }
 
   // prepare the writer to write the image
   vtkSmartPointer<vtkDICOMWriter> writer =
     vtkSmartPointer<vtkDICOMWriter>::New();
-  if (generator)
-  {
-    writer->SetGenerator(generator);
-  }
+  writer->SetGenerator(generator);
   writer->SetMetaData(meta);
+  if (options->verbatim)
+  {
+    writer->SetImageType(NULL);
+  }
   writer->SetFilePrefix(outfile);
   writer->SetFilePattern("%s/IM-0001-%04.4d.dcm");
   writer->TimeAsVectorOn();
