@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2015 David Gobbi
+  Copyright (c) 2012-2019 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -123,48 +123,76 @@ void vtkDICOMApplyPaletteExecute(
       // for monochrome mapping when palette is supplemental
       bool monochrome = false;
       double windowCenter = 0.0;
-      double windowScale = 1.0;
+      double windowWidth = 1.0;
+      double slope = 1.0;
+      double inter = 0.0;
+      bool isSigmoid = false;
+      bool isLinearExact = false;
       if (supplemental)
       {
         // check if this frame is specifically monochrome
-        monochrome = meta->GetAttributeValue(
-          i, f, DC::PixelPresentation).Matches("MONOCHROME*");
+        monochrome = meta->Get(i, f, DC::PixelPresentation).Matches(
+          "MONOCHROME*");
 
         // use the window that is suggested in the data
-        const vtkDICOMValue& wc =
-          meta->GetAttributeValue(i, f, DC::WindowCenter);
-        const vtkDICOMValue& ww =
-          meta->GetAttributeValue(i, f, DC::WindowWidth);
-        double windowWidth = 0.0;
+        const vtkDICOMValue& wc = meta->Get(i, f, DC::WindowCenter);
+        const vtkDICOMValue& ww = meta->Get(i, f, DC::WindowWidth);
         if (wc.IsValid() && ww.IsValid())
         {
           windowCenter = wc.AsDouble();
           windowWidth = ww.AsDouble();
         }
 
-        // for CT images, the rescaling must be taken into account
-        const vtkDICOMValue& rs =
-          meta->GetAttributeValue(i, f, DC::RescaleSlope);
-        const vtkDICOMValue& ri =
-          meta->GetAttributeValue(i, f, DC::RescaleIntercept);
-        if (rs.IsValid() && ri.IsValid())
+        // check which function to apply
+        const vtkDICOMValue& wf = meta->Get(i, f, DC::VOILUTFunction);
+        if (wf.IsValid())
         {
-          double slope = rs.AsDouble();
-          double inter = ri.AsDouble();
-          if (slope > 0)
-          {
-            windowWidth = windowWidth / slope;
-            windowCenter = (windowCenter - inter) / slope;
-          }
+          isLinearExact = wf.Matches("LINEAR_EXACT");
+          isSigmoid = wf.Matches("SIGMOID");
         }
 
-        // a scale parameter is more efficient and convenient
-        if (windowWidth > 0)
+        // for CT images, the rescaling must be taken into account
+        const vtkDICOMValue& rs = meta->Get(i, f, DC::RescaleSlope);
+        const vtkDICOMValue& ri = meta->Get(i, f, DC::RescaleIntercept);
+        if (rs.IsValid() && ri.IsValid())
         {
-          windowScale = 255.0/windowWidth;
+          slope = rs.AsDouble();
+          inter = ri.AsDouble();
+          if (slope == 0.0)
+          {
+            slope = 1.0;
+          }
         }
       }
 
+      // these values are used to compute the VOI LUT (DICOM PS3.3 C.11.2.1)
+      double ww = windowWidth;
+      double wc = windowCenter;
+      if (!isLinearExact && !isSigmoid)
+      {
+        ww -= 1.0;
+        wc -= 0.5;
+      }
+      ww = ww/slope;
+      wc = (wc - inter)/slope;
+      if (ww < 0.0)
+      {
+        ww = 0.0;
+      }
+      double ws = (isSigmoid ? -4.0 : 255.0);
+      if (ww != 0.0)
+      {
+        ws /= ww;
+      }
+      else
+      {
+        ws = 1.0;
+        isSigmoid = false;
+      }
+      double wl = wc - 0.5*ww;
+      double wh = wc + 0.5*ww;
+
+      // loop through slices
       for (int yIdx = extent[2]; yIdx <= extent[3]; yIdx++)
       {
         T *inPtr = inPtrZ + inIncY*(yIdx - extent[2]);
@@ -186,10 +214,25 @@ void vtkDICOMApplyPaletteExecute(
           int idx = inPtr[0] - firstValueMapped;
           if (monochrome || (supplemental && idx < 0))
           {
-            // use monochrome
-            double fidx = (inPtr[0] - windowCenter)*windowScale + 127.5;
-            fidx = (fidx >= 0.0 ? fidx : 0.0);
-            fidx = (fidx <= 255.0 ? fidx : 255.0);
+            double fidx = inPtr[0];
+            if (isSigmoid)
+            {
+              fidx = 255.0/(1.0 + exp((fidx - wc)*ws));
+            }
+            else if (fidx <= wl)
+            {
+              fidx = 0.0;
+            }
+            else if (fidx > wh)
+            {
+              fidx = 255.0;
+            }
+            else
+            {
+              fidx = (fidx - wc)*ws + 127.5;
+              fidx = (fidx >= 0.0 ? fidx : 0.0);
+              fidx = (fidx <= 255.0 ? fidx : 255.0);
+            }
             int gray = static_cast<int>(fidx + 0.5);
             outPtr[0] = gray;
             outPtr[1] = gray;
@@ -242,15 +285,14 @@ int vtkDICOMApplyPalette::RequestInformation(
   this->IsSupplemental = 0;
   bool hasPalette = false;
 
-  if (meta && meta->GetAttributeValue(DC::SamplesPerPixel).Matches(1))
+  if (meta && meta->Get(DC::SamplesPerPixel).Matches(1))
   {
     // Check if PhotometricInterpretation is PALETTE COLOR
-    const vtkDICOMValue& u = meta->GetAttributeValue(
-      DC::PhotometricInterpretation);
+    const vtkDICOMValue& u = meta->Get(DC::PhotometricInterpretation);
     hasPalette = u.Matches("PALETTE?COLOR");
 
     // Check the PixelPresentation (enhanced files)
-    const vtkDICOMValue& v = meta->GetAttributeValue(DC::PixelPresentation);
+    const vtkDICOMValue& v = meta->Get(DC::PixelPresentation);
     this->IsSupplemental = (v.Matches("COLOR") ||
                             v.Matches("MIXED") ||
                             v.Matches("TRUE_COLOR"));
@@ -273,18 +315,21 @@ int vtkDICOMApplyPalette::RequestInformation(
     // Modify the meta data, the image has become an RGB image
     vtkDICOMMetaData *outMeta = vtkDICOMMetaData::SafeDownCast(
       outInfo->Get(vtkDICOMAlgorithm::META_DATA()));
-    outMeta->SetAttributeValue(DC::SamplesPerPixel, 3);
-    outMeta->SetAttributeValue(DC::PhotometricInterpretation, "RGB");
-    outMeta->SetAttributeValue(DC::PixelRepresentation, 0);
-    outMeta->SetAttributeValue(DC::BitsAllocated, 8);
-    outMeta->SetAttributeValue(DC::BitsStored, 8);
-    outMeta->SetAttributeValue(DC::HighBit, 7);
-    outMeta->RemoveAttribute(DC::RedPaletteColorLookupTableDescriptor);
-    outMeta->RemoveAttribute(DC::GreenPaletteColorLookupTableDescriptor);
-    outMeta->RemoveAttribute(DC::BluePaletteColorLookupTableDescriptor);
-    outMeta->RemoveAttribute(DC::RedPaletteColorLookupTableData);
-    outMeta->RemoveAttribute(DC::GreenPaletteColorLookupTableData);
-    outMeta->RemoveAttribute(DC::BluePaletteColorLookupTableData);
+    outMeta->Set(DC::SamplesPerPixel, 3);
+    outMeta->Set(DC::PhotometricInterpretation, "RGB");
+    outMeta->Set(DC::PixelRepresentation, 0);
+    outMeta->Set(DC::BitsAllocated, 8);
+    outMeta->Set(DC::BitsStored, 8);
+    outMeta->Set(DC::HighBit, 7);
+    outMeta->Erase(DC::RedPaletteColorLookupTableDescriptor);
+    outMeta->Erase(DC::GreenPaletteColorLookupTableDescriptor);
+    outMeta->Erase(DC::BluePaletteColorLookupTableDescriptor);
+    outMeta->Erase(DC::RedPaletteColorLookupTableData);
+    outMeta->Erase(DC::GreenPaletteColorLookupTableData);
+    outMeta->Erase(DC::BluePaletteColorLookupTableData);
+    outMeta->Erase(DC::SegmentedRedPaletteColorLookupTableData);
+    outMeta->Erase(DC::SegmentedGreenPaletteColorLookupTableData);
+    outMeta->Erase(DC::SegmentedBluePaletteColorLookupTableData);
   }
 
   return 1;
