@@ -16,6 +16,7 @@
 
 #include "vtkObject.h"
 #include "vtkDICOMModule.h" // For export macro
+#include "vtkDICOMConfig.h" // For configuration details
 
 
 class vtkStringArray;
@@ -38,11 +39,7 @@ public:
   vtkTypeMacro(vtkDICOMCompiler, vtkObject);
 
   //! Print a summary of the contents of this object.
-#ifdef VTK_OVERRIDE
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
-#else
-  void PrintSelf(ostream& os, vtkIndent indent);
-#endif
+  void PrintSelf(ostream& os, vtkIndent indent) VTK_DICOM_OVERRIDE;
 
   //@{
   //! Set the file name.
@@ -273,15 +270,12 @@ protected:
   friend class vtkDICOMCompilerInternalFriendship;
 
 private:
-#ifdef VTK_DELETE_FUNCTION
-  vtkDICOMCompiler(const vtkDICOMCompiler&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkDICOMCompiler&) VTK_DELETE_FUNCTION;
-#elif __cplusplus >= 201103L
+#ifdef VTK_DICOM_DELETE
+  vtkDICOMCompiler(const vtkDICOMCompiler&) VTK_DICOM_DELETE;
+  void operator=(const vtkDICOMCompiler&) VTK_DICOM_DELETE;
+#else
   vtkDICOMCompiler(const vtkDICOMCompiler&) = delete;
   void operator=(const vtkDICOMCompiler&) = delete;
-#else
-  vtkDICOMCompiler(const vtkDICOMCompiler&);
-  void operator=(const vtkDICOMCompiler&);
 #endif
 };
 
