@@ -99,6 +99,14 @@ struct vtkDICOMDirectory::FileInfo
   vtkDICOMItem ImageRecord;
 };
 
+struct vtkDICOMDirectory::FileInfoPair
+{
+  const char *Key;
+  FileInfo *Info;
+
+  FileInfoPair(const char *key, FileInfo *ptr) : Key(key), Info(ptr) {}
+};
+
 struct vtkDICOMDirectory::SeriesInfo
 {
   // -- PATIENT --
@@ -114,16 +122,110 @@ struct vtkDICOMDirectory::SeriesInfo
   vtkDICOMItem  SeriesRecord;
   vtkDICOMValue SeriesUID;
   unsigned int SeriesNumber;
-  std::vector<FileInfo> Files;
+  // -- INSTANCES --
+  std::list<FileInfo> Files;
+  std::vector<FileInfoPair> FilesByUID;
   bool QueryMatched;
 };
 
+bool vtkDICOMDirectory::CompareInstanceUIDs(
+  const FileInfoPair& p, const char *uid)
+{
+  return (vtkDICOMUtilities::CompareUIDs(p.Key, uid) < 0);
+}
+
 bool vtkDICOMDirectory::CompareInstance(
   const FileInfo &fi1, const FileInfo &fi2)
 {
-  return (fi1.InstanceNumber < fi2.InstanceNumber);
+  if (fi1.InstanceNumber != fi2.InstanceNumber)
+  {
+    return (fi1.InstanceNumber < fi2.InstanceNumber);
+  }
+
+  // fall back to filename comparison
+  if (fi1.FileName != 0 && fi2.FileName != 0)
+  {
+    return (strcmp(fi1.FileName, fi2.FileName) < 0);
+  }
+
+  // null filename sorts before non-null filename
+  return (fi2.FileName != 0);
 }
 
+bool vtkDICOMDirectory::CompareSeriesUIDs(
+  const SeriesInfo *si, const char *uid)
+{
+  return (vtkDICOMUtilities::CompareUIDs(
+    si->SeriesUID.GetCharData(), uid) < 0);
+}
+
+bool vtkDICOMDirectory::CompareSeriesIds(
+  const SeriesInfo *si1, const SeriesInfo *si2)
+{
+  // Compare patient, then study, then series
+  const char *patientID1 = si1->PatientID.GetCharData();
+  patientID1 = (patientID1 ? patientID1 : "");
+  const char *patientID2 = si2->PatientID.GetCharData();
+  patientID2 = (patientID2 ? patientID2 : "");
+
+  int c = strcmp(patientID1, patientID2);
+
+  if (c == 0)
+  {
+    c = vtkDICOMUtilities::CompareUIDs(
+      si1->StudyUID.GetCharData(),
+      si2->StudyUID.GetCharData());
+
+    if (c == 0)
+    {
+      c = vtkDICOMUtilities::CompareUIDs(
+        si1->SeriesUID.GetCharData(),
+        si2->SeriesUID.GetCharData());
+    }
+  }
+
+  return (c < 0);
+}
+
+bool vtkDICOMDirectory::CompareSeriesInfo(
+  const SeriesInfo &si1, const SeriesInfo &si2)
+{
+  // Use PatientName to sort the patients
+  const char *patientName1 = si1.PatientName.GetCharData();
+  patientName1 = (patientName1 ? patientName1 : "");
+  const char *patientName2 = si2.PatientName.GetCharData();
+  patientName2 = (patientName2 ? patientName2 : "");
+
+  int c = strcmp(patientName1, patientName2);
+
+  if (c == 0)
+  {
+    // Use StudyDate and StudyTime to sort the studies
+    const char *studyDate1 = si1.StudyDate.GetCharData();
+    const char *studyDate2 = si2.StudyDate.GetCharData();
+    if (studyDate1 && studyDate2)
+    {
+      c = strcmp(studyDate1, studyDate2);
+      if (c == 0)
+      {
+        const char *studyTime1 = si1.StudyTime.GetCharData();
+        const char *studyTime2 = si2.StudyTime.GetCharData();
+        if (studyTime1 && studyTime2)
+        {
+          c = strcmp(studyTime1, studyTime2);
+        }
+      }
+    }
+
+    if (c == 0)
+    {
+      // Use SeriesNumber to sort the series
+      c = si1.SeriesNumber - si2.SeriesNumber;
+    }
+  }
+
+  return (c < 0);
+}
 //----------------------------------------------------------------------------
 // These are the attributes used for a directory scan
 
@@ -205,6 +307,10 @@ class vtkDICOMDirectory::SeriesInfoList
   : public std::list<vtkDICOMDirectory::SeriesInfo>
 {};
 
+class vtkDICOMDirectory::SeriesInfoVector
+  : public std::vector<vtkDICOMDirectory::SeriesInfo *>
+{};
+
 //----------------------------------------------------------------------------
 // A helper class for building a sorted list of unique tags
 class SortedTags : public std::vector<vtkDICOMTag>
@@ -955,7 +1061,7 @@ void vtkDICOMDirectory::AddSeriesFileNames(
   }
   else if (n < 0 || study != n-1)
   {
-    vtkErrorMacro("AddSeriesFileNames: non-monotonically increasing study")
+    vtkErrorMacro("AddSeriesFileNames: non-monotonically increasing study");
     return;
   }
 
@@ -986,7 +1092,7 @@ void vtkDICOMDirectory::AddSeriesFileNames(
   }
   else
   {
-    vtkErrorMacro("AddSeriesFileNames: non-monotonically increasing patient")
+    vtkErrorMacro("AddSeriesFileNames: non-monotonically increasing patient");
     return;
   }
 
@@ -1206,9 +1312,9 @@ void vtkDICOMDirectory::SortFiles(vtkStringArray *input)
   // will be stored at patient, study, or series level instead
   SortedTags skip;
 
-  // List of files
-  SeriesInfoList sortedFiles;
-  SeriesInfoList::iterator li;
+  // List of all series that have been found
+  SeriesInfoList seriesList; // in order of discovery
+  SeriesInfoVector seriesByUID; // sorted by UID
 
   vtkIdType numberOfStrings = input->GetNumberOfValues();
 
@@ -1293,174 +1399,217 @@ void vtkDICOMDirectory::SortFiles(vtkStringArray *input)
       continue;
     }
 
-    // Insert the file into the sorted list
+    // Create a FileInfo record and find the series it belongs to
     FileInfo fileInfo;
     fileInfo.InstanceNumber = meta->Get(DC::InstanceNumber).AsUnsignedInt();
     fileInfo.FileName = fileName.c_str(); // stored in input StringArray
     fileInfo.ImageUID = meta->Get(DC::SOPInstanceUID);
 
-    const vtkDICOMValue& patientNameValue = meta->Get(DC::PatientName);
-    const vtkDICOMValue& patientIDValue = meta->Get(DC::PatientID);
-    const vtkDICOMValue& studyDateValue = meta->Get(DC::StudyDate);
-    const vtkDICOMValue& studyTimeValue = meta->Get(DC::StudyTime);
     const vtkDICOMValue& studyUIDValue = meta->Get(DC::StudyInstanceUID);
     const vtkDICOMValue& seriesUIDValue = meta->Get(DC::SeriesInstanceUID);
     unsigned int seriesNumber = meta->Get(DC::SeriesNumber).AsUnsignedInt();
 
-    const char *patientName = patientNameValue.GetCharData();
-    const char *patientID = patientIDValue.GetCharData();
-    const char *studyDate = studyDateValue.GetCharData();
-    const char *studyTime = studyTimeValue.GetCharData();
     const char *studyUID = studyUIDValue.GetCharData();
     const char *seriesUID = seriesUIDValue.GetCharData();
     const char *imageUID = fileInfo.ImageUID.GetCharData();
 
-    patientName = (patientName ? patientName : "");
-    patientID = (patientID ? patientID : "");
-
+    bool sameFile = false;
     bool foundSeries = false;
-    for (li = sortedFiles.begin(); li != sortedFiles.end(); ++li)
+
+    // Locate the first potential match
+    SeriesInfoVector::iterator vib =
+      std::lower_bound(seriesByUID.begin(), seriesByUID.end(), seriesUID,
+                       CompareSeriesUIDs);
+
+    // Iterate through all possible matches
+    for (SeriesInfoVector::iterator vi = vib;
+         vi != seriesByUID.end() &&
+         vtkDICOMUtilities::CompareUIDs((*vi)->SeriesUID.GetCharData(),
+                                        seriesUID) == 0;
+         ++vi)
     {
-      // Compare patient, then study, then series.
-      const char *patientName2 = li->PatientName.GetCharData();
-      patientName2 = (patientName2 ? patientName2 : "");
-      const char *patientID2 = li->PatientID.GetCharData();
-      patientID2 = (patientID2 ? patientID2 : "");
-      int c = strcmp(patientID2, patientID);
-      if (c != 0 || patientID[0] == '\0')
+      SeriesInfo &v = *(*vi);
+
+      // For files that lack the mandatory SeriesInstanceUID,
+      // we also check whether SeriesNumber is the same
+      if ((seriesUID == 0 || seriesUID[0] == '\0') &&
+          seriesNumber != v.SeriesNumber)
       {
-        // Use ID to identify patient, but use name to sort.
-        int c2 = strcmp(patientName2, patientName);
-        c = (c2 == 0 ? c : c2);
+        continue;
       }
-      if (c == 0)
+
+      // Ensure that the StudyInstanceUID also matches
+      if (vtkDICOMUtilities::CompareUIDs(v.StudyUID.GetCharData(),
+                                         studyUID) != 0)
       {
-        c = vtkDICOMUtilities::CompareUIDs(
-          studyUID, li->StudyUID.GetCharData());
-        if (c != 0 || studyUID == 0)
-        {
-          // Use UID to identify study, but use date to sort.
-          int c2 = 0;
-          const char *studyDate2 = li->StudyDate.GetCharData();
-          if (studyDate && studyDate2)
-          {
-            c2 = strcmp(studyDate2, studyDate);
-            if (c2 == 0)
-            {
-              const char *studyTime2 = li->StudyTime.GetCharData();
-              if (studyTime2 && studyTime)
-              {
-                c2 = strcmp(studyTime, studyTime2);
-              }
-            }
-          }
-          c = (c2 == 0 ? c : c2);
-        }
-        if (c == 0)
-        {
-          c = vtkDICOMUtilities::CompareUIDs(
-            seriesUID, li->SeriesUID.GetCharData());
-          if (c != 0 || seriesUID == 0)
-          {
-            // Use UID to identify series, but use series number to sort.
-            int c2 = li->SeriesNumber - seriesNumber;
-            c = (c2 == 0 ? c : c2);
-          }
-        }
+        continue;
       }
-      if (c == 0 && seriesUID != 0)
+
+      // Prepare to insert this file into the series
+      std::vector<FileInfoPair>::iterator im =
+        std::lower_bound(v.FilesByUID.begin(), v.FilesByUID.end(),
+          imageUID, CompareInstanceUIDs);
+
+      if (im != v.FilesByUID.end())
       {
-        // Use UID to identify the image, but use instance number to sort.
-        bool sameFile = false;
-        bool repeatUID = false;
-        for (std::vector<FileInfo>::iterator im = li->Files.begin();
-             im != li->Files.end(); ++im)
+        // Check if this SOPInstanceUID is a duplicate
+        if (vtkDICOMUtilities::CompareUIDs(imageUID, im->Key) == 0)
         {
-          if (vtkDICOMUtilities::CompareUIDs(
-                imageUID, im->ImageUID.GetCharData()) == 0)
-          {
-            // Duplicate UID! Check InstanceNumber.
-            if (im->InstanceNumber == fileInfo.InstanceNumber)
-            {
-              sameFile = vtkDICOMFile::SameFile(
-                im->FileName, fileInfo.FileName);
-              repeatUID = true;
-              break;
-            }
-            else if (imageUID && imageUID[0] != '\0')
-            {
-              repeatUID = true;
-            }
-          }
-        }
-        if (repeatUID)
-        {
-          if (sameFile)
+          // Duplicate UID! Check to see if it is the same file
+          // (SameFile() is expensive, so check InstanceNumber first)
+          FileInfo &f = *im->Info;
+          if (f.InstanceNumber == fileInfo.InstanceNumber &&
+              vtkDICOMFile::SameFile(f.FileName, fileInfo.FileName))
           {
+            // Let's ignore this file
+            sameFile = true;
             break;
           }
-          continue;
-        }
 
-        std::vector<FileInfo>::iterator pos =
-          li->Files.insert(
-            std::upper_bound(li->Files.begin(), li->Files.end(), fileInfo,
-              CompareInstance), fileInfo);
-        this->FillImageRecord(&pos->ImageRecord, meta, &skip[0], skip.size());
-        li->QueryMatched |= queryMatched;
-        foundSeries = true;
-        break;
-      }
-      else if (c >= 0)
-      {
-        break;
+          if (imageUID == 0 || imageUID[0] == '\0')
+          {
+            // If SOPInstanceUID is missing, advance iterator to end
+            // (this is necessary to keep the sort stable)
+            do { ++im; } while (im != v.FilesByUID.end() &&
+                                vtkDICOMUtilities::CompareUIDs(
+                                  im->Key, imageUID) == 0);
+          }
+          else
+          {
+            // For duplicate UID, continue to the next series
+            continue;
+          }
+        }
       }
+
+      // Insert this image into the series and break
+      v.Files.push_back(fileInfo);
+      FileInfo &f = v.Files.back();
+      v.FilesByUID.insert(im, FileInfoPair(f.ImageUID.GetCharData(), &f));
+      this->FillImageRecord(&f.ImageRecord, meta, &skip[0], skip.size());
+      v.QueryMatched |= queryMatched;
+      foundSeries = true;
+      break;
+    }
+
+    if (sameFile)
+    {
+      // This same file was already encountered, so skip it
+      continue;
     }
 
     if (!foundSeries)
     {
-      li = sortedFiles.insert(li, SeriesInfo());
-      li->PatientName = patientNameValue;
-      li->PatientID = patientIDValue;
-      li->StudyDate = studyDateValue;
-      li->StudyUID = studyUIDValue;
-      li->SeriesUID = seriesUIDValue;
-      li->SeriesNumber = seriesNumber;
-      li->Files.push_back(fileInfo);
-      li->QueryMatched = queryMatched;
-      this->FillPatientRecord(&li->PatientRecord, meta);
-      this->FillStudyRecord(&li->StudyRecord, meta);
-      this->FillSeriesRecord(&li->SeriesRecord, meta);
-      skip.SetFrom(li->PatientRecord, li->StudyRecord, li->SeriesRecord);
-      this->FillImageRecord(&li->Files.back().ImageRecord, meta,
-                            &skip[0], skip.size());
+      // Use this image to begin a new series
+      seriesList.push_back(SeriesInfo());
+      SeriesInfo &v = seriesList.back();
+      seriesByUID.insert(vib, &v);
+      v.PatientName = meta->Get(DC::PatientName);
+      v.PatientID = meta->Get(DC::PatientID);
+      v.StudyDate = meta->Get(DC::StudyDate);
+      v.StudyTime = meta->Get(DC::StudyTime);
+      v.StudyUID = studyUIDValue;
+      v.SeriesUID = seriesUIDValue;
+      v.SeriesNumber = seriesNumber;
+      v.Files.push_back(fileInfo);
+      FileInfo &f = v.Files.back();
+      v.FilesByUID.push_back(FileInfoPair(f.ImageUID.GetCharData(), &f));
+      v.QueryMatched = queryMatched;
+      this->FillPatientRecord(&v.PatientRecord, meta);
+      this->FillStudyRecord(&v.StudyRecord, meta);
+      this->FillSeriesRecord(&v.SeriesRecord, meta);
+      skip.SetFrom(v.PatientRecord, v.StudyRecord, v.SeriesRecord);
+      this->FillImageRecord(&f.ImageRecord, meta, &skip[0], skip.size());
     }
   }
 
+  // Remove any series that do not match the query
+  seriesByUID.clear();
+  SeriesInfoList::iterator li = seriesList.begin();
+  while (li != seriesList.end())
+  {
+    if (!li->QueryMatched)
+    {
+      SeriesInfoList::iterator ci = li;
+      ++li;
+      seriesList.erase(ci);
+    }
+    else
+    {
+      seriesByUID.push_back(&(*li));
+      ++li;
+    }
+  }
+
+  SeriesInfo *lastInfo = 0;
+
+  // Force consistent PatientName, StudyDate, StudyTime keys for sorting
+  std::sort(seriesByUID.begin(), seriesByUID.end(), CompareSeriesIds);
+  for (SeriesInfoVector::iterator vi = seriesByUID.begin();
+       vi != seriesByUID.end(); ++vi)
+  {
+    SeriesInfo &v = *(*vi);
+
+    // Is this a new patient or a new study?
+    if (!lastInfo || v.PatientID != lastInfo->PatientID)
+    {
+      const char *cp = v.PatientName.GetCharData();
+      size_t l = v.PatientName.GetVL();
+      if (!cp)
+      {
+        // if PatientName key is missing, use PatientID as replacment
+        cp = v.PatientID.GetCharData();
+        l = v.PatientID.GetVL();
+      }
+      if (cp)
+      {
+        // Strip padding space
+        while (l > 0 && cp[l-1] == ' ') { --l; }
+        // Make PatientName key lower-case for case-insensitive sorting
+        vtkDICOMCharacterSet cs = v.PatientName.GetCharacterSet();
+        v.PatientName = vtkDICOMValue(
+          vtkDICOMVR::PN, vtkDICOMCharacterSet::ISO_IR_192,
+          cs.CaseFoldedUTF8(cp, l));
+      }
+      lastInfo = &v;
+    }
+    else if (v.StudyUID != lastInfo->StudyUID)
+    {
+      v.PatientName = lastInfo->PatientName;
+      lastInfo = &v;
+    }
+    else
+    {
+      v.PatientName = lastInfo->PatientName;
+      v.StudyDate = lastInfo->StudyDate;
+      v.StudyTime = lastInfo->StudyTime;
+    }
+  }
+
+  // Sort by PatientName, StudyDate, StudyTime, and SeriesNumber
+  seriesList.sort(CompareSeriesInfo);
+
   // Visit each series and call AddSeriesFileNames
   int patientCount = this->GetNumberOfPatients();
   int studyCount = this->GetNumberOfStudies();
 
-  vtkDICOMValue lastStudyUID;
-  vtkDICOMValue lastPatientID;
+  lastInfo = 0;
 
-  for (li = sortedFiles.begin(); li != sortedFiles.end(); ++li)
+  for (li = seriesList.begin(); li != seriesList.end(); ++li)
   {
     SeriesInfo &v = *li;
-    if (!v.QueryMatched) { continue; }
 
     // Is this a new patient or a new study?
-    if (!lastPatientID.IsValid() || v.PatientID != lastPatientID)
+    if (!lastInfo || v.PatientID != lastInfo->PatientID)
     {
-      lastPatientID = v.PatientID;
       patientCount++;
-      lastStudyUID = v.StudyUID;
       studyCount++;
+      lastInfo = &v;
     }
-    else if (!lastStudyUID.IsValid() || v.StudyUID != lastStudyUID)
+    else if (v.StudyUID != lastInfo->StudyUID)
     {
-      lastStudyUID = v.StudyUID;
       studyCount++;
+      lastInfo = &v;
     }
 
     vtkSmartPointer<vtkStringArray> sa =
@@ -1468,10 +1617,13 @@ void vtkDICOMDirectory::SortFiles(vtkStringArray *input)
     vtkIdType n = static_cast<vtkIdType>(v.Files.size());
     sa->SetNumberOfValues(n);
     std::vector<const vtkDICOMItem *> imageRecords(n);
+    li->Files.sort(CompareInstance);
+    std::list<FileInfo>::iterator fi = li->Files.begin();
     for (vtkIdType i = 0; i < n; i++)
     {
-      sa->SetValue(i, v.Files[i].FileName);
-      imageRecords[i] = &v.Files[i].ImageRecord;
+      sa->SetValue(i, fi->FileName);
+      imageRecords[i] = &fi->ImageRecord;
+      ++fi;
     }
     this->AddSeriesFileNames(
       patientCount-1, studyCount-1, sa,
@@ -1533,13 +1685,59 @@ private:
 
 bool SimpleSQL::Open(const char *fname)
 {
-  int r = sqlite3_open_v2(fname, &this->DBase, SQLITE_OPEN_READONLY, NULL);
+  // convert to URI for use with sqlite3_open()
+  const char uri_reserved[] = " !#$%&'()*+,:;=?@[]";
+
+  // first, get absolute path
+  vtkDICOMFilePath path(fname);
+  std::string fullpath = path.GetRealPath();
+
+  // build the URI using percent encoding
+  std::string uri = "file://";
+
+  for (size_t i = 0; i < fullpath.length(); i++)
+  {
+    bool use_percent = false;
+    char c = fullpath[i];
+    if (c < ' ' || c > '~')
+    {
+      use_percent = true;
+    }
+    else for (size_t j = 0; j < sizeof(uri_reserved); j++)
+    {
+      if (c == uri_reserved[j])
+      {
+        use_percent = true;
+        break;
+      }
+    }
+
+    if (use_percent)
+    {
+      char enc[4];
+      sprintf(enc, "%%%2.2x", static_cast<unsigned char>(c));
+      uri += enc;
+    }
+    else
+    {
+      uri.push_back(c);
+    }
+  }
+
+  // we need to use "immutable" or else a read-only open will fail
+  // if the .sql-wal file is missing (and we definitely want to open
+  // the file in read-only mode, we never ever wish to modify the file!)
+  uri += "?mode=ro&immutable=1";
+
+  int r = sqlite3_open_v2(uri.c_str(), &this->DBase,
+                          SQLITE_OPEN_READONLY|SQLITE_OPEN_URI, 0);
   if (r == SQLITE_OK)
   {
     char *errmsg;
     r = sqlite3_exec(this->DBase, "BEGIN TRANSACTION", NULL, NULL, &errmsg);
     this->InTransaction = (r == SQLITE_OK);
   }
+
   return (r == SQLITE_OK);
 }
 
