@@ -401,8 +401,10 @@ private:
   class StudyVector;
   class PatientVector;
   struct FileInfo;
+  struct FileInfoPair;
   struct SeriesInfo;
   class SeriesInfoList;
+  class SeriesInfoVector;
   class VisitedVector;
 
   vtkDICOMItem *Query;
@@ -421,6 +423,18 @@ private:
 
   //! Compare FileInfo entries by instance number
   static bool CompareInstance(const FileInfo &fi1, const FileInfo &fi2);
+
+  //! Compare SeriesInfo entries by SeriesUID
+  static bool CompareSeriesUIDs(const SeriesInfo *si, const char *uid);
+
+  //! Compare SeriesInfo entries by PatientID, StudyUID, and SeriesUID
+  static bool CompareSeriesIds(const SeriesInfo *li1, const SeriesInfo *li2);
+
+  //! Compare SeriesInfo entries by PatientName, StudyDate, and SeriesNumber
+  static bool CompareSeriesInfo(const SeriesInfo &li1, const SeriesInfo &li2);
+
+  //! Compare SOPInstanceUID to a FileInfo entry.
+  static bool CompareInstanceUIDs(const FileInfoPair& p, const char *uid);
 };
 
 #endif
