@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2015 David Gobbi
+  Copyright (c) 2012-2019 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -200,7 +200,7 @@ std::string vtkDICOMFilePath::Join(const std::string& second) const
           {
             endpos++;
           }
-          // Remove the preceeding part of the path
+          // Remove the preceding part of the path
           l = path.length();
           size_t m = RootLength(path);
           if (l > m && path[l-1] == sep)
@@ -383,6 +383,29 @@ bool vtkDICOMFilePath::IsDirectory() const
   return result;
 }
 
+//----------------------------------------------------------------------------
+bool vtkDICOMFilePath::IsSpecial() const
+{
+  bool result = false;
+#ifdef _WIN32
+  wchar_t *widepath = ConvertToWideChar(this->Path.c_str());
+  if (widepath)
+  {
+    DWORD a = GetFileAttributesW(widepath);
+    delete [] widepath;
+    result = ((a & FILE_ATTRIBUTE_DEVICE) != 0);
+  }
+#else
+  struct stat fs;
+  if (stat(this->Path.c_str(), &fs) == 0 &&
+      !S_ISDIR(fs.st_mode) && !S_ISREG(fs.st_mode))
+  {
+    result = true;
+  }
+#endif
+  return result;
+}
+
 //----------------------------------------------------------------------------
 bool vtkDICOMFilePath::IsSymlink() const
 {
@@ -635,7 +658,7 @@ size_t vtkDICOMFilePath::RootLength(const std::string& path)
   // does not allows substitutions such as "/" for "\" or "." and "..".
   //  \\?\A:\ (the root of a device)
   //  \\?\UNC\server\share\ (a UNC path prefix)
-  // Finally, the special "\\?\" prefix is used to name system devices:
+  // Finally, the special "\\.\" prefix is used to name system devices:
   //  \\.\DEVICE (name of a special devices)
   if (l >= 4 && HasExtendedPrefix(path))
   {
