@@ -17,6 +17,7 @@
 #include "vtkObject.h"
 #include "vtkStdString.h" // For std::string
 #include "vtkDICOMModule.h" // For export macro
+#include "vtkDICOMConfig.h" // For configuration details
 #include "vtkDICOMTag.h" // For method parameter
 
 class vtkIntArray;
@@ -45,14 +46,11 @@ class VTKDICOM_EXPORT vtkDICOMGenerator : public vtkObject
 {
 public:
   //! Static method for construction.
+  static vtkDICOMGenerator *New();
   vtkTypeMacro(vtkDICOMGenerator, vtkObject);
 
   //! Print information about this object.
-#ifdef VTK_OVERRIDE
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
-#else
-  void PrintSelf(ostream& os, vtkIndent indent);
-#endif
+  void PrintSelf(ostream& os, vtkIndent indent) VTK_DICOM_OVERRIDE;
 
   //@{
   //! Generate an instance of one of the supported classes.
@@ -61,7 +59,7 @@ public:
    *  information for a vtkImageData object, it will populate the
    *  attributes of the supplied vtkDICOMMetaData object.
    */
-  virtual bool GenerateInstance(vtkInformation *) = 0;
+  virtual bool GenerateInstance(vtkInformation *);
   //@}
 
   //@{
@@ -73,6 +71,19 @@ public:
   vtkDICOMMetaData *GetMetaData();
   //@}
 
+  //@{
+  //! Copy extended attributes from source (default: Off).
+  /*!
+   *  If this is off (the default), then only attributes that are part
+   *  of the base SOP class will be copied from the source.  Otherwise,
+   *  all attributes (standard and private) will be copied.  No validation
+   *  is performed on attributes that aren't part of the base SOP class.
+   */
+  vtkSetMacro(Extended, int);
+  vtkBooleanMacro(Extended, int);
+  vtkGetMacro(Extended, int);
+  //@}
+
   //@{
   //! Create a multi-frame object (default: Off).
   /*!
@@ -339,6 +350,15 @@ protected:
     const DC::EnumType *tags, vtkDICOMMetaData *source);
   //@}
 
+  //! Copy all atributes into the meta data, excluding blacklisted ones.
+  /*!
+   *  The blacklist must be terminated with DC::ItemDelimitationItem.
+   *  The blacklist may be set to NULL.
+   */
+  virtual bool CopyAttributes(
+    const DC::EnumType *blacklist, vtkDICOMMetaData *source);
+  //@}
+
   //! Compute aspect ratio from spacing.
   static void ComputeAspectRatio(const double spacing[2], int aspect[2]);
 
@@ -401,6 +421,9 @@ protected:
   //! The UID generator.
   vtkDICOMUIDGenerator *UIDGenerator;
 
+  //! Whether to copy attributes that aren't in the base SOP class.
+  int Extended;
+
   //! Whether to prefer multi-frame files over single-frame.
   int MultiFrame;
 
@@ -484,15 +507,12 @@ protected:
   vtkIntArray *RangeArray;
 
 private:
-#ifdef VTK_DELETE_FUNCTION
-  vtkDICOMGenerator(const vtkDICOMGenerator&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkDICOMGenerator&) VTK_DELETE_FUNCTION;
-#elif __cplusplus >= 201103L
+#ifdef VTK_DICOM_DELETE
+  vtkDICOMGenerator(const vtkDICOMGenerator&) VTK_DICOM_DELETE;
+  void operator=(const vtkDICOMGenerator&) VTK_DICOM_DELETE;
+#else
   vtkDICOMGenerator(const vtkDICOMGenerator&) = delete;
   void operator=(const vtkDICOMGenerator&) = delete;
-#else
-  vtkDICOMGenerator(const vtkDICOMGenerator&);
-  void operator=(const vtkDICOMGenerator&);
 #endif
 };
 
