@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2015 David Gobbi
+  Copyright (c) 2012-2019 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -18,7 +18,7 @@
 #include <stddef.h>
 
 //----------------------------------------------------------------------------
-const char *vtkDICOMImageCodec::UIDs[16] = {
+const char *vtkDICOMImageCodec::UIDs[21] = {
   "1.2.840.10008.1.2.1",     // LittleEndian
   "1.2.840.10008.1.2.2",     // BigEndian
   "1.2.840.10008.1.2.5",     // RLE
@@ -32,26 +32,27 @@ const char *vtkDICOMImageCodec::UIDs[16] = {
   "1.2.840.10008.1.2.4.91",  // JPEG2KLossless
   "1.2.840.10008.1.2.4.100", // MPEG2ML
   "1.2.840.10008.1.2.4.101", // MPEG2HL
-  "1.2.840.10008.1.2.4.102", // MPEG2HP
-  "1.2.840.10008.1.2.4.103", // MPEG2BD
+  "1.2.840.10008.1.2.4.102", // MPEG4HPL41
+  "1.2.840.10008.1.2.4.103", // MPEG4HPL41BD
+  "1.2.840.10008.1.2.4.104", // MPEG4HPL42V2D
+  "1.2.840.10008.1.2.4.105", // MPEG4HPL42V3D
+  "1.2.840.10008.1.2.4.106", // MPEG4HPL42Stereo
+  "1.2.840.10008.1.2.4.107", // HEVCMPL51
+  "1.2.840.10008.1.2.4.108", // HEVCM10PL51
   0
 };
 
 //----------------------------------------------------------------------------
 vtkDICOMImageCodec::ImageFormat::ImageFormat(vtkDICOMMetaData *meta)
 {
-  this->Rows = meta->GetAttributeValue(DC::Rows).AsInt();
-  this->Columns = meta->GetAttributeValue(DC::Columns).AsInt();
-  this->BitsAllocated = meta->GetAttributeValue(DC::BitsAllocated).AsInt();
-  this->BitsStored = meta->GetAttributeValue(DC::BitsStored).AsInt();
-  this->PixelRepresentation =
-    meta->GetAttributeValue(DC::PixelRepresentation).AsInt();
-  this->SamplesPerPixel =
-    meta->GetAttributeValue(DC::SamplesPerPixel).AsInt();
-  this->PlanarConfiguration =
-    meta->GetAttributeValue(DC::PlanarConfiguration).AsInt();
-  const char *lossy =
-    meta->GetAttributeValue(DC::AllowLossyCompression).GetCharData();
+  this->Rows = meta->Get(DC::Rows).AsInt();
+  this->Columns = meta->Get(DC::Columns).AsInt();
+  this->BitsAllocated = meta->Get(DC::BitsAllocated).AsInt();
+  this->BitsStored = meta->Get(DC::BitsStored).AsInt();
+  this->PixelRepresentation = meta->Get(DC::PixelRepresentation).AsInt();
+  this->SamplesPerPixel = meta->Get(DC::SamplesPerPixel).AsInt();
+  this->PlanarConfiguration = meta->Get(DC::PlanarConfiguration).AsInt();
+  const char *lossy = meta->Get(DC::AllowLossyCompression).GetCharData();
   this->AllowLossyCompression = (lossy && strncmp(lossy, "YES", 3) == 0);
 }
 
