@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2015 David Gobbi
+  Copyright (c) 2012-2019 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -13,7 +13,7 @@
 =========================================================================*/
 #include "vtkDICOMReferenceCount.h"
 
-#include <vtkWindows.h>
+#include "vtkWindows.h"
 
 #if defined(_WIN32)
 unsigned int vtkDICOMReferenceCount::operator--()
