@@ -22,11 +22,7 @@ class VTKDICOM_EXPORT vtkDICOMSorter : public vtkDICOMFileSorter
 public:
   //@{
   vtkTypeMacro(vtkDICOMSorter,vtkDICOMFileSorter);
-#ifdef VTK_OVERRIDE
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
-#else
-  void PrintSelf(ostream& os, vtkIndent indent);
-#endif
+  void PrintSelf(ostream& os, vtkIndent indent) VTK_DICOM_OVERRIDE;
   static vtkDICOMSorter *New();
   //@}
 
@@ -43,15 +39,12 @@ protected:
   ~vtkDICOMSorter();
 
 private:
-#ifdef VTK_DELETE_FUNCTION
-  vtkDICOMSorter(const vtkDICOMSorter&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkDICOMSorter&) VTK_DELETE_FUNCTION;
-#elif __cplusplus >= 201103L
+#ifdef VTK_DICOM_DELETE
+  vtkDICOMSorter(const vtkDICOMSorter&) VTK_DICOM_DELETE;
+  void operator=(const vtkDICOMSorter&) VTK_DICOM_DELETE;
+#else
   vtkDICOMSorter(const vtkDICOMSorter&) = delete;
   void operator=(const vtkDICOMSorter&) = delete;
-#else
-  vtkDICOMSorter(const vtkDICOMSorter&);
-  void operator=(const vtkDICOMSorter&);
 #endif
 };
 
