@@ -17,6 +17,7 @@
 #include "vtkObject.h"
 #include "vtkStdString.h" // For std::string
 #include "vtkDICOMModule.h" // For export macro
+#include "vtkDICOMConfig.h" // For configuration details
 #include "vtkDICOMTag.h" // For method parameter
 
 class vtkStringArray;
@@ -33,11 +34,7 @@ public:
   vtkTypeMacro(vtkDICOMUtilities, vtkObject);
 
   //! Print a summary of the contents of this object.
-#ifdef VTK_OVERRIDE
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
-#else
-  void PrintSelf(ostream& os, vtkIndent indent);
-#endif
+  void PrintSelf(ostream& os, vtkIndent indent) VTK_DICOM_OVERRIDE;
   //@}
 
   //@{
@@ -210,15 +207,12 @@ protected:
   static char ImplementationVersionName[17];
 
 private:
-#ifdef VTK_DELETE_FUNCTION
-  vtkDICOMUtilities(const vtkDICOMUtilities&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkDICOMUtilities&) VTK_DELETE_FUNCTION;
-#elif __cplusplus >= 201103L
+#ifdef VTK_DICOM_DELETE
+  vtkDICOMUtilities(const vtkDICOMUtilities&) VTK_DICOM_DELETE;
+  void operator=(const vtkDICOMUtilities&) VTK_DICOM_DELETE;
+#else
   vtkDICOMUtilities(const vtkDICOMUtilities&) = delete;
   void operator=(const vtkDICOMUtilities&) = delete;
-#else
-  vtkDICOMUtilities(const vtkDICOMUtilities&);
-  void operator=(const vtkDICOMUtilities&);
 #endif
 };
 
