@@ -60,7 +60,10 @@ public:
     US = 0x1e, //!< Unsigned Short
     UT = 0x1f, //!< Unlimited Text
     OX = 0x20, //!< Either OB or OW (for dict entries, not data elements)
-    XS = 0x21  //!< Either SS or US (for dict entries, not data elements)
+    XS = 0x21, //!< Either SS or US (for dict entries, not data elements)
+    OV = 0x22, //!< Other Very Long
+    SV = 0x23, //!< Signed Very Long
+    UV = 0x24, //!< Unsigned Very Long
   };
 
   //@{
@@ -90,25 +93,25 @@ public:
   //@}
 
   //@{
-  //! The VRs OB, OD, OF, OL, OW, SQ, UC, UN, UR, UT require a 32-bit VL.
+  //! The VRs OB, OD, OF, OL, OW, OV, SQ, UC, UN, UR, UT require a 32-bit VL.
   bool HasLongVL() const {
-    return (((1ull << this->Key) & 0xb223e001u) != 0); }
+    return (((1ull << this->Key) & 0x1cb223e001ull) != 0); }
 
   //! The VRs SH, LO, PN, ST, LT, UC, and UT use SpecificCharacterSet.
   bool HasSpecificCharacterSet() const {
-    return (((1ull << this->Key) & 0x828c1800u) != 0); }
+    return (((1ull << this->Key) & 0x828c1800ull) != 0); }
 
   //! This is true for all VRs whose value is stored as text.
   bool HasTextValue() const {
-    return (((1ull << this->Key) & 0xa78c1cf6u) != 0); }
+    return (((1ull << this->Key) & 0xa78c1cf6ull) != 0); }
 
   //! This is true for for all VRs that store numbers.
   /*!
-   *  The VRs included are IS, DS, US, UL, SS, SL, FL, FD.  The VRs
-   *  OB, OW, OF, OL, and OD are not included.
+   *  The VRs included are IS, DS, US, UL, UV, SS, SL, SV, FL, FD.  The VRs
+   *  OB, OW, OL, OV, OF, and OD are not included.
    */
   bool HasNumericValue() const {
-    return (((1ull << this->Key) & 0x48500740u) != 0); }
+    return (((1ull << this->Key) & 0x1848500740ull) != 0); }
 
   //! The VRs ST, LT, and UT carry only one value.
   /*!
@@ -117,7 +120,7 @@ public:
    * is an illegal character in UR.
    */
   bool HasSingleValue() const {
-    return (((1ull << this->Key) & 0x80801000u) != 0); }
+    return (((1ull << this->Key) & 0x80801000ull) != 0); }
   //@}
 
   //@{
@@ -133,8 +136,8 @@ private:
   unsigned char Key;
 
   static const unsigned char *VRTable[256];
-  static const unsigned char TypeTable[34];
-  static const char TextTable[34][4];
+  static const unsigned char TypeTable[37];
+  static const char TextTable[37][4];
 };
 
 VTKDICOM_EXPORT ostream& operator<<(ostream& o, const vtkDICOMVR& a);
