@@ -102,9 +102,9 @@ void StringConversion(
       }
       else
       {
-        int d = 0;
+        OT d = 0;
         sbs >> d;
-        *v++ = static_cast<OT>(d);
+        *v++ = d;
       }
       if (k + 1 < n)
       {
@@ -941,6 +941,18 @@ vtkDICOMValue::vtkDICOMValue(
   this->CreateValue(vr, data, count);
 }
 
+vtkDICOMValue::vtkDICOMValue(
+  vtkDICOMVR vr, const long long *data, size_t count)
+{
+  this->CreateValue(vr, data, count);
+}
+
+vtkDICOMValue::vtkDICOMValue(
+  vtkDICOMVR vr, const unsigned long long *data, size_t count)
+{
+  this->CreateValue(vr, data, count);
+}
+
 vtkDICOMValue::vtkDICOMValue(
   vtkDICOMVR vr, const float *data, size_t count)
 {
@@ -1502,6 +1514,14 @@ void vtkDICOMValue::GetValuesT(VT *v, size_t c, size_t s) const
       NumericalConversion(
         static_cast<const ValueT<unsigned int> *>(this->V)->Data+s, v, c);
       break;
+    case VTK_LONG_LONG:
+      NumericalConversion(
+        static_cast<const ValueT<long long> *>(this->V)->Data+s, v, c);
+      break;
+    case VTK_UNSIGNED_LONG_LONG:
+      NumericalConversion(
+        static_cast<const ValueT<unsigned long long> *>(this->V)->Data+s, v, c);
+      break;
     case VTK_FLOAT:
       NumericalConversion(
         static_cast<const ValueT<float> *>(this->V)->Data+s, v, c);
@@ -1582,6 +1602,18 @@ void vtkDICOMValue::GetValues(unsigned int *v, size_t c, size_t s) const
   this->GetValuesT(v, c, s);
 }
 
+void vtkDICOMValue::GetValues(long long *v, size_t c, size_t s) const
+{
+  assert((s + c) <= this->V->NumberOfValues);
+  this->GetValuesT(v, c, s);
+}
+
+void vtkDICOMValue::GetValues(unsigned long long *v, size_t c, size_t s) const
+{
+  assert((s + c) <= this->V->NumberOfValues);
+  this->GetValuesT(v, c, s);
+}
+
 void vtkDICOMValue::GetValues(float *v, size_t c, size_t s) const
 {
   assert((s + c) <= this->V->NumberOfValues);
@@ -1917,6 +1949,7 @@ std::string vtkDICOMValue::AsString() const
       this->V->VR != vtkDICOMVR::OW &&
       this->V->VR != vtkDICOMVR::OB &&
       this->V->VR != vtkDICOMVR::OL &&
+      this->V->VR != vtkDICOMVR::OV &&
       this->V->VR != vtkDICOMVR::OF &&
       this->V->VR != vtkDICOMVR::OD)
   {
@@ -2061,8 +2094,8 @@ void vtkDICOMValue::AppendValueToString(
   const char *cp = 0;
   const char *dp = 0;
   double f = 0.0;
-  int d = 0;
-  size_t u = 0;
+  long long d = 0;
+  unsigned long long u = 0;
   vtkDICOMTag a;
 
   if (this->V == 0)
@@ -2104,6 +2137,12 @@ void vtkDICOMValue::AppendValueToString(
     case VTK_UNSIGNED_INT:
       u = static_cast<const ValueT<unsigned int> *>(this->V)->Data[i];
       break;
+    case VTK_LONG_LONG:
+      d = static_cast<const ValueT<long long> *>(this->V)->Data[i];
+      break;
+    case VTK_UNSIGNED_LONG_LONG:
+      u = static_cast<const ValueT<unsigned long long> *>(this->V)->Data[i];
+      break;
     case VTK_FLOAT:
       f = static_cast<const ValueT<float> *>(this->V)->Data[i];
       break;
@@ -2227,11 +2266,13 @@ void vtkDICOMValue::AppendValueToString(
            this->V->Type == VTK_SHORT ||
            this->V->Type == VTK_UNSIGNED_SHORT ||
            this->V->Type == VTK_INT ||
-           this->V->Type == VTK_UNSIGNED_INT)
+           this->V->Type == VTK_UNSIGNED_INT ||
+           this->V->Type == VTK_LONG_LONG ||
+           this->V->Type == VTK_UNSIGNED_LONG_LONG)
   {
     // simple code to convert an integer to a string
-    char text[16];
-    size_t ti = 16;
+    char text[20];
+    size_t ti = 20;
 
     // if d is nonzero, set u to abs(d)
     if (d > 0)
@@ -2255,7 +2296,7 @@ void vtkDICOMValue::AppendValueToString(
       text[--ti] = '-';
     }
 
-    str.append(&text[ti], &text[16]);
+    str.append(&text[ti], &text[20]);
   }
   else if (this->V->Type == VTK_DICOM_TAG)
   {
@@ -2892,6 +2933,11 @@ bool vtkDICOMValue::Matches(const vtkDICOMValue& value) const
     // OL must match exactly
     match = ValueT<unsigned int>::Compare(value.V, this->V);
   }
+  else if (vr == vtkDICOMVR::OV)
+  {
+    // OV must match exactly
+    match = ValueT<unsigned int>::Compare(value.V, this->V);
+  }
   else if (vr == vtkDICOMVR::OF)
   {
     // OF must match exactly
@@ -2912,6 +2958,11 @@ bool vtkDICOMValue::Matches(const vtkDICOMValue& value) const
     // Match if any value matches
     match = ValueT<int>::CompareEach(value.V, this->V);
   }
+  else if (type == VTK_LONG_LONG || type == VTK_UNSIGNED_LONG_LONG)
+  {
+    // Match if any value matches
+    match = ValueT<long long>::CompareEach(value.V, this->V);
+  }
   else if (type == VTK_FLOAT)
   {
     // Match if any value matches
@@ -2995,6 +3046,10 @@ bool vtkDICOMValue::operator==(const vtkDICOMValue& o) const
           case VTK_UNSIGNED_INT:
             r = ValueT<int>::Compare(a, b);
             break;
+          case VTK_LONG_LONG:
+          case VTK_UNSIGNED_LONG_LONG:
+            r = ValueT<long long>::Compare(a, b);
+            break;
           case VTK_FLOAT:
             r = ValueT<float>::Compare(a, b);
             break;
@@ -3093,6 +3148,10 @@ ostream& operator<<(ostream& os, const vtkDICOMValue& v)
   {
     os << "longwords[" << m << "]";
   }
+  else if (vr == vtkDICOMVR::OV)
+  {
+    os << "verylongwords[" << m << "]";
+  }
   else if (vr == vtkDICOMVR::OF)
   {
     os << "floats[" << m << "]";
