@@ -102,90 +102,6 @@ vtkNIFTIReader::~vtkNIFTIReader()
   }
 }
 
-//----------------------------------------------------------------------------
-namespace { // anonymous namespace
-
-void vtkNIFTIReaderSwapHeader(nifti_1_header *hdr)
-{
-  // Common to NIFTI and Analyze 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->sizeof_hdr,    1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->extents,       1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->session_error, 1, 2);
-  vtkByteSwap::SwapVoidRange(hdr->dim,            8, 2);
-  vtkByteSwap::SwapVoidRange(&hdr->intent_p1,     1, 4); // unused in 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->intent_p2,     1, 4); // unused in 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->intent_p3,     1, 4); // unused in 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->intent_code,   1, 2); // unused in 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->datatype,      1, 2);
-  vtkByteSwap::SwapVoidRange(&hdr->bitpix,        1, 2);
-  vtkByteSwap::SwapVoidRange(&hdr->slice_start,   1, 2); // dim_un0 in 7.5
-  vtkByteSwap::SwapVoidRange(hdr->pixdim,         8, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->vox_offset,    1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->scl_slope,     1, 4); // unused in 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->scl_inter,     1, 4); // unused in 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->slice_end,     1, 2); // unused in 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->cal_max,       1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->cal_min,       1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->slice_duration,1, 4); // compressed in 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->toffset,       1, 4); // verified in 7.5
-  vtkByteSwap::SwapVoidRange(&hdr->glmax,         1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->glmin,         1, 4);
-
-  // All NIFTI-specific (meaning is totally different in Analyze 7.5)
-  if (strncmp(hdr->magic, "ni1", 4) == 0 ||
-      strncmp(hdr->magic, "n+1", 4) == 0)
-  {
-    vtkByteSwap::SwapVoidRange(&hdr->qform_code,    1, 2);
-    vtkByteSwap::SwapVoidRange(&hdr->sform_code,    1, 2);
-    vtkByteSwap::SwapVoidRange(&hdr->quatern_b,     1, 4);
-    vtkByteSwap::SwapVoidRange(&hdr->quatern_c,     1, 4);
-    vtkByteSwap::SwapVoidRange(&hdr->quatern_d,     1, 4);
-    vtkByteSwap::SwapVoidRange(&hdr->qoffset_x,     1, 4);
-    vtkByteSwap::SwapVoidRange(&hdr->qoffset_y,     1, 4);
-    vtkByteSwap::SwapVoidRange(&hdr->qoffset_z,     1, 4);
-    vtkByteSwap::SwapVoidRange(hdr->srow_x,         4, 4);
-    vtkByteSwap::SwapVoidRange(hdr->srow_y,         4, 4);
-    vtkByteSwap::SwapVoidRange(hdr->srow_z,         4, 4);
-  }
-}
-
-void vtkNIFTIReaderSwapHeader(nifti_2_header *hdr)
-{
-  vtkByteSwap::SwapVoidRange(&hdr->sizeof_hdr,    1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->datatype,      1, 2);
-  vtkByteSwap::SwapVoidRange(&hdr->bitpix,        1, 2);
-  vtkByteSwap::SwapVoidRange(hdr->dim,            8, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->intent_p1,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->intent_p2,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->intent_p3,     1, 8);
-  vtkByteSwap::SwapVoidRange(hdr->pixdim,         8, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->vox_offset,    1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->scl_slope,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->scl_inter,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->cal_max,       1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->cal_min,       1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->slice_duration,1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->toffset,       1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->slice_start,   1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->slice_end,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->qform_code,    1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->sform_code,    1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->quatern_b,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->quatern_c,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->quatern_d,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->qoffset_x,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->qoffset_y,     1, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->qoffset_z,     1, 8);
-  vtkByteSwap::SwapVoidRange(hdr->srow_x,         4, 8);
-  vtkByteSwap::SwapVoidRange(hdr->srow_y,         4, 8);
-  vtkByteSwap::SwapVoidRange(hdr->srow_z,         4, 8);
-  vtkByteSwap::SwapVoidRange(&hdr->slice_code,    1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->xyzt_units,    1, 4);
-  vtkByteSwap::SwapVoidRange(&hdr->intent_code,   1, 4);
-}
-
-} // end anonymous namespace
-
 //----------------------------------------------------------------------------
 vtkNIFTIHeader *vtkNIFTIReader::GetNIFTIHeader()
 {
@@ -409,7 +325,6 @@ int vtkNIFTIReader::CanReadFile(const char *filename)
 #else
   // use wide character
   const wchar_t *uhdrname = fp.Wide();
-  fprintf(stderr, "uhdrname\n");
 #endif
 #else
   const char *uhdrname = hdrname;
@@ -594,7 +509,7 @@ int vtkNIFTIReader::RequestInformation(
     {
       if (NIFTI_NEEDS_SWAP(*hdr2))
       {
-        vtkNIFTIReaderSwapHeader(hdr2);
+        vtkNIFTIHeader::ByteSwapHeader(hdr2);
         isLittleEndian = !isLittleEndian;
       }
       this->NIFTIHeader->SetHeader(hdr2);
@@ -603,7 +518,7 @@ int vtkNIFTIReader::RequestInformation(
     {
       if (NIFTI_NEEDS_SWAP(*hdr1))
       {
-        vtkNIFTIReaderSwapHeader(hdr1);
+        vtkNIFTIHeader::ByteSwapHeader(hdr1);
         isLittleEndian = !isLittleEndian;
       }
       // convert NIFTIv1 header into NIFTIv2
@@ -800,7 +715,7 @@ int vtkNIFTIReader::RequestInformation(
   // 1) via a quaternion (orientation and offset, i.e. rigid-body)
   // 2) via a matrix (used to store e.g. the results of registration)
   //
-  // A NIFTI file can have both a quaternion (qform) and matrix (xform)
+  // A NIFTI file can have both a quaternion (qform) and matrix (sform)
   // stored in the same file.  The NIFTI documentation recommends that
   // the qform be used to record the "scanner anatomical" coordinates
   // and that the sform, if present, be used to define a secondary
@@ -880,7 +795,7 @@ int vtkNIFTIReader::RequestInformation(
   //       NIFTI, which allows us to preserve positive spacing and retain
   //       a well-behaved rotation matrix, by using these equations:
   //
-  //         J = number_of_slices - j - 1
+  //         K = number_of_slices - k - 1
   //
   //         M14 = qoffset_x - (number_of_slices - 1)*pixdim[3]*R13
   //         M24 = qoffset_y - (number_of_slices - 1)*pixdim[3]*R23
@@ -888,7 +803,7 @@ int vtkNIFTIReader::RequestInformation(
   //
   //       This will give us data that will be well-behaved in VTK, at
   //       the expense of making VTK slice numbers not match with
-  //       the original NIFTI slice numbers.  NIFTY slice 0 will become
+  //       the original NIFTI slice numbers.  NIFTI slice 0 will become
   //       VTK slice N-1, and the order will be reversed.
   //
   // -- Matrix Representation --
@@ -899,7 +814,7 @@ int vtkNIFTIReader::RequestInformation(
   // flip-factor as there is in the quaternion representation.
   //
   // Let S be the matrix stored in the NIFTI header, and let M be our
-  // desired coordinate tranformation from VTK data coordinates X,Y,Z
+  // desired coordinate transformation from VTK data coordinates X,Y,Z
   // to NIFTI data coordinates x,y,z (see discussion above for more
   // information).  Let's consider the cases where the determinant
   // is positive, or negative.
@@ -1198,7 +1113,6 @@ int vtkNIFTIReader::RequestData(
 #else
   // use wide character
   const wchar_t *uimgname = fpi.Wide();
-  fprintf(stderr, "uhdrname\n");
 #endif
 #else
   const char *uimgname = imgname;
