@@ -19,7 +19,11 @@ if (!(t)) \
   rval |= 1; \
 }
 
+#ifdef VTK_IN_VTK
+int TestDICOMItem(int argc, char *argv[])
+#else
 int main(int argc, char *argv[])
+#endif
 {
   int rval = 0;
   const char *exename = (argc > 0 ? argv[0] : "TestDICOMSequence");
