@@ -15,9 +15,9 @@ if vtk.vtkVersion.GetVTKMajorVersion() < 6:
     sys.stderr.write("This test requires VTK 6 or higher.\n");
     sys.exit(0)
 
-m.SetAttributeValue(vtk.vtkDICOMTag(0x0008, 0x0005), 'ISO_IR 100')
+m.Set(vtk.vtkDICOMTag(0x0008, 0x0005), 'ISO_IR 100')
 
-v = m.GetAttributeValue(vtk.vtkDICOMTag(0x0008, 0x0005))
+v = m.Get(vtk.vtkDICOMTag(0x0008, 0x0005))
 
 if v.AsString() != 'ISO_IR 100':
     sys.exit(1)
